pub struct StanzaToken { /* private fields */ }Expand description
Track stanza transmission through the
StanzaStream up to the peer.
Implementations
Sourceimpl StanzaToken
impl StanzaToken
Sourcepub async fn wait_for(&mut self, state: StanzaStage) -> Option<StanzaState>
pub async fn wait_for(&mut self, state: StanzaStage) -> Option<StanzaState>
Wait for the stanza transmission to reach the given state.
If the stanza is removed from tracking before that state is reached,
None is returned.
Sourcepub fn state(&self) -> StanzaState
pub fn state(&self) -> StanzaState
Read the current transmission state.